# HydroPrep.py
# takes dem and spits out filled dem, flow direction raster and accumulation grid, as well as ascii versions of the dem and acc rasters
# Compatible with ArcMap 9.2
# RAD 10-11-07

#import system modules and create geoprocessor object
import arcgisscripting
gp = arcgisscripting.create()


try:
    # Set local variables
    WorkingDirectory = gp.GetParameterAsText(0)
    InSurfaceRaster = gp.GetParameterAsText(1)
    ProjectName = gp.GetParameterAsText(2)
    FillRaster = WorkingDirectory + "\\" + ProjectName+"_fill"  

    # Check out Spatial Analyst extension license
    gp.CheckOutExtension("Spatial")

    # Process: Fill
    gp.Fill_sa(InSurfaceRaster, FillRaster)

    FlowDirectionRaster = WorkingDirectory + "\\" + ProjectName + "_fdir"
    InFlowDirOption = "NORMAL"    
        
    # Process: FlowDirection
    gp.FlowDirection_sa(FillRaster, FlowDirectionRaster, InFlowDirOption)

    AccumulationRaster = WorkingDirectory + "\\" + ProjectName+"_acc"

    # Process: FlowAccumulation
    gp.FlowAccumulation_sa(FlowDirectionRaster, AccumulationRaster, "", "INTEGER")

    AsciiDEM = WorkingDirectory + "\\" + ProjectName + "dem.txt"
    AsciiAcc = WorkingDirectory + "\\" + ProjectName + "acc.txt"
    
    # Process: RasterToASCII_conversion of DEM
    gp.RasterToASCII_conversion(InSurfaceRaster, AsciiDEM)

    # Process: RasterToASCII_conversion of Acc
    gp.RasterToASCII_conversion(AccumulationRaster, AsciiAcc)


except:
    # If an error occurred while running a tool, then print the messages.
    print gp.GetMessages()